@@ -2,6 +2,6 @@ strength <- function(object, ...) UseMethod("strength")
 
 strength.wsrf <- function (object, ...) {
 
-    object$model$estimation["strength"]
+  object[[.STRENGTH_IDX]]
 
-} 
\ No newline at end of file
+}
\ No newline at end of file
